package com.njyunzhi.ubpa.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.njyunzhi.ubpa.common.*;
import com.njyunzhi.ubpa.entity.SysSetting;
import com.njyunzhi.ubpa.entity.TaUser;
import com.njyunzhi.ubpa.service.ISysSettingService;
import com.njyunzhi.ubpa.service.ITaUserService;
import com.njyunzhi.ubpa.vo.LoginParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;


@Api(tags = "企业登入/登出")
@RestController
@RequestMapping("/admin/org")
public class OrgLoginController extends BaseController {

    @Autowired
    ITaUserService iTaUserService;

    @Autowired
    ISysSettingService iSysSettingService;

    @PostMapping("/login")
    @ApiOperation(value="登录", notes = "登录", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean login(@ApiParam("登录参数") @RequestBody LoginParam loginParam) throws Exception {
        if (null == loginParam) {
            return ResponseBean.error("账户或密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String userName = loginParam.getUserName();
        String password = loginParam.getPassword();

        if (StringUtils.isEmpty(userName) || StringUtils.isEmpty(password)) {
            return ResponseBean.error("账户或密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        TaUser taUser = iTaUserService.getExistBy("login_name", userName, false, true);
        if (null == taUser) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (taUser.getStatus() != Constants.STATUS_NORMAL) {
            return ResponseBean.error("账户异常", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (!checkPassword(password, taUser.getPassword(), taUser.getUserId())) {
            return ResponseBean.error("账户或密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        taUser.setPassword(null);

        Map<String, Object> res = new HashMap<>();
        res.put("user", taUser);
        res.put("roleAlias", Constants.LOGIN_TYPE_ORG);

        // 生成 token
        StpUtil.login(taUser.getUserId(), Constants.LOGIN_TYPE_ORG);
        res.put("token", StpUtil.getTokenValue());

        // 获取填报客户端地址
        SysSetting sysSetting = iSysSettingService.getById(Constants.SETTING_REPORT_URL);
        res.put(Constants.SETTING_REPORT_URL, sysSetting.getContent());

        return ResponseBean.success(res);
    }

    private boolean checkPassword(String src, String targ, String salt) {
        return EncryptUtils.md5(src, salt).equals(targ);
    }
}
