package com.njyunzhi.ubpa.controller;

import com.njyunzhi.ubpa.common.BaseController;
import com.njyunzhi.ubpa.common.Constants;
import com.njyunzhi.ubpa.common.DateUtils;
import com.njyunzhi.ubpa.common.ResponseBean;
import com.njyunzhi.ubpa.entity.TaOrg;
import com.njyunzhi.ubpa.entity.TaUser;
import com.njyunzhi.ubpa.entity.TsResumeWorkForm;
import com.njyunzhi.ubpa.service.ITaOrgService;
import com.njyunzhi.ubpa.service.ITaResumeWorkFormService;
import com.njyunzhi.ubpa.service.ITsResumeWorkFormService;
import com.njyunzhi.ubpa.vo.StatisValue;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Api(tags = "统计")
@RestController
@RequestMapping("/")
public class StatisController extends BaseController {

    @Autowired
    ITaOrgService iTaOrgService;

    @Autowired
    ITaResumeWorkFormService iTaResumeWorkFormService;

    @Autowired
    ITsResumeWorkFormService iTsResumeWorkFormService;

    private int getInt(Object val) {
        if (null == val) return 0;
        return Integer.parseInt(val.toString());
    }

    @RequestMapping(value="/admin/statis/comm",method= RequestMethod.GET)
    @ApiOperation(value="工作台统计", notes = "工作台统计", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean comm() throws Exception {

        // 企业总数
        int orgTotal = iTaOrgService.countTotal();
        // 有数据企业
        int existsDataNum = iTaOrgService.countExistsData();
        // 今日汇总
        LocalDateTime now = LocalDateTime.now();
        String today = DateUtils.toString(now, "yyyy-MM-dd");
        Map<String, Integer> statToday = iTaResumeWorkFormService.statisNum(null, DateUtils.getDayStart(today), DateUtils.getDayEnd(today));
        int todayReportNum = getInt(statToday.get("total"));
        int todayNormalNum = getInt(statToday.get("normal"));
//        int todayReportNum = iTsResumeWorkFormService.getValueByParams(null, Constants.STATIS_TOTAL, today);
//        int todayNormalNum = iTsResumeWorkFormService.getValueByParams(null, Constants.STATIS_NROMAL, today);
        // 昨日汇总
        String yestoday = DateUtils.toString(LocalDateTime.now().minusDays(1), "yyyy-MM-dd");
        Integer yestodayReportNum = iTsResumeWorkFormService.getValueByParams(null, Constants.STATIS_TOTAL, yestoday);

        Map<String, Integer> res = new HashMap<>();
        res.put("orgTotalNum", orgTotal);
        res.put("noDataOrgNum", orgTotal - existsDataNum);
        res.put("todayReportNum", todayReportNum);
        res.put("todayNormalNum", todayNormalNum);
        res.put("yestodayReportNum", yestodayReportNum);

        return ResponseBean.success(res);
    }

    @RequestMapping(value="/admin/statis/org/comm",method= RequestMethod.GET)
    @ApiOperation(value="企业工作台统计", notes = "企业工作台统计", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean orgComm() throws Exception {

        TaUser taUser = currentUser();
        if (null == taUser) {
            return ResponseBean.error("暂无权限");
        }

        String orgId = taUser.getOrgId();

        // 企业总数
        int orgTotal = iTsResumeWorkFormService.getOrgTotal(orgId, Constants.STATIS_TOTAL);
        // 今日汇总
        LocalDateTime now = LocalDateTime.now();
        String today = DateUtils.toString(now, "yyyy-MM-dd");
        Map<String, Integer> statToday = iTaResumeWorkFormService.statisNum(orgId, DateUtils.getDayStart(today), DateUtils.getDayEnd(today));
        int todayReportNum = getInt(statToday.get("total"));
        int todayNormalNum = getInt(statToday.get("normal"));
//        int todayReportNum = iTsResumeWorkFormService.getValueByParams(orgId, Constants.STATIS_TOTAL, today);
//        int todayNormalNum = iTsResumeWorkFormService.getValueByParams(orgId, Constants.STATIS_NROMAL, today);
        // 昨日汇总
        String yestoday = DateUtils.toString(LocalDateTime.now().minusDays(1), "yyyy-MM-dd");
        Integer yestodayReportNum = iTsResumeWorkFormService.getValueByParams(orgId, Constants.STATIS_TOTAL, yestoday);

        Map<String, Integer> res = new HashMap<>();
        res.put("orgTotalNum", orgTotal);
        res.put("todayReportNum", todayReportNum);
        res.put("todayNormalNum", todayNormalNum);
        res.put("yestodayReportNum", yestodayReportNum);

        return ResponseBean.success(res);
    }

    /**
     * 企业数据汇总
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/admin/statis/org/total",method= RequestMethod.GET)
    @ApiOperation(value="企业数据汇总", notes = "企业数据汇总", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getOrgTotal() throws Exception {
        List<TaOrg> orgList = iTsResumeWorkFormService.getAllOrgPersonNum();
        return ResponseBean.success(orgList);
    }

    /**
     * 企业数据汇总
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/admin/statis/org/daily",method= RequestMethod.GET)
    @ApiOperation(value="企业数据汇总", notes = "企业数据汇总", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getOrgDaily(@ApiParam("企业ID") @RequestParam(value = "orgId", required = false) String orgId,
                                    @ApiParam(value = "开始日期", example = "2022-05-01") @RequestParam("startDate") String startDate,
                                    @ApiParam(value = "统计天数") @RequestParam("days") Integer days) throws Exception {

        Map<String, List> res = new HashMap<>();
        res.put(Constants.STATIS_NROMAL, iTsResumeWorkFormService.getOrgInfo(orgId, Constants.STATIS_NROMAL, startDate, days));
        res.put(Constants.STATIS_ABNROMAL, iTsResumeWorkFormService.getOrgInfo(orgId, Constants.STATIS_ABNROMAL, startDate, days));

        return ResponseBean.success(res);
    }
}
