package com.njyunzhi.ubpa.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.ubpa.common.*;
import com.njyunzhi.ubpa.entity.SysUser;
import com.njyunzhi.ubpa.entity.TaOrg;
import com.njyunzhi.ubpa.entity.TaUser;
import com.njyunzhi.ubpa.service.ITaOrgService;
import com.njyunzhi.ubpa.vo.FormExport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.njyunzhi.ubpa.service.ITaResumeWorkFormService;
import com.njyunzhi.ubpa.entity.TaResumeWorkForm;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.net.URL;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
    * 复工申请 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-05-01
 */

@Api(tags = "复工申请")
@RestController
@RequestMapping("/")
public class TaResumeWorkFormController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaResumeWorkFormController.class);

    @Autowired
    public ITaResumeWorkFormService iTaResumeWorkFormService;

    @Autowired
    public ITaOrgService iTaOrgService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/resume-work-form",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taResumeWorkFormList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                             @ApiParam("企业ID") @RequestParam(value ="orgId", required = false) String orgId,
                                             @ApiParam("申请人") @RequestParam(value ="userName", required = false) String userName,
                                             @ApiParam("是否全部企业") @RequestParam(value ="isAll", defaultValue = "false") Boolean isAll,
                                             @ApiParam("是否异常") @RequestParam(value ="isAbnormal", defaultValue = "false") Boolean isAbnormal,
                                             @ApiParam("是否删除") @RequestParam(value ="isDelete", defaultValue = "false") Boolean isDelete,
                                             @ApiParam(value = "起始时间", example = "2022-03-01") @RequestParam(value ="start", required = false) String start,
                                             @ApiParam(value = "结束时间", example = "2022-03-31") @RequestParam(value ="end", required = false) String end,
                                             @ApiParam(value = "删除起始", example = "2022-03-01") @RequestParam(value ="deleteStart", required = false) String deleteStart,
                                             @ApiParam(value = "删除结束", example = "2022-03-31") @RequestParam(value ="deleteEnd", required = false) String deleteEnd) throws Exception{

        if (!isAll && StringUtils.isEmpty(orgId)) {
            return ResponseBean.error("请选择企业");
        }

        LocalDateTime startDate = DateUtils.getDayStart(start);
        LocalDateTime endDate = DateUtils.getDayEnd(end);
        LocalDateTime deleteStartDate = DateUtils.getDayStart(deleteStart);
        LocalDateTime deleteEndDate = DateUtils.getDayEnd(deleteEnd);

        IPage<TaResumeWorkForm> pg = new Page<>(pageNum, pageSize);

        IPage<TaResumeWorkForm> result = iTaResumeWorkFormService.getPageBy(pg,
                orgId,
                userName,
                startDate,
                endDate,
                !isDelete ? Constants.STATUS_NORMAL : Constants.STATUS_DELETE,
                isAbnormal,
                deleteStartDate,
                deleteEndDate
        );

        return ResponseBean.success(result);
    }

    /**
     * 分页查询列表
     * @return
     */
    @RequestMapping(value="/admin/resume-work-form/export",method= RequestMethod.GET)
    @ApiOperation(value="申请导出", notes = "申请导出", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean formExport(@ApiParam("企业ID") @RequestParam(value ="orgId", required = false) String orgId,
                                   @ApiParam("申请人") @RequestParam(value ="userName", required = false) String userName,
                                   @ApiParam(value = "起始时间", example = "2022-03-01") @RequestParam(value ="start", required = false) String start,
                                   @ApiParam(value = "结束时间", example = "2022-03-31") @RequestParam(value ="end", required = false) String end,
                                   @ApiParam("是否删除") @RequestParam(value ="isDelete", defaultValue = "false") Boolean isDelete,
                           HttpServletResponse response) throws Exception{
        if (StringUtils.isEmpty(orgId)) {
            return ResponseBean.error("请选择企业");
        }

        LocalDateTime startDate = DateUtils.getDayStart(start);
        LocalDateTime endDate = DateUtils.getDayEnd(end);

        List<FormExport> list = iTaResumeWorkFormService.formExport(orgId,
                userName,
                startDate,
                endDate,
                !isDelete ? Constants.STATUS_NORMAL : Constants.STATUS_DELETE
        );

        for(int i = 0; i < list.size(); i += 1) {
            FormExport item = list.get(i);
            item.setIndex(String.valueOf(i + 1));

            if (!StringUtils.isEmpty(item.getAntigenImage())) {
                item.setAntigenImageURL(new URL(item.getAntigenImage()));
            }
            if (!StringUtils.isEmpty(item.getNucleicImage())) {
                item.setNucleicImageURL(new URL(item.getNucleicImage()));
            }
        }

        // 文件名称 = 企业名称 + 人数 + 日期
        TaOrg taOrg = iTaOrgService.getById(orgId);
        List<String> fileNameParts = new ArrayList<>();
        fileNameParts.add(taOrg.getOrgName());
        if (list.size() > 0) {
            fileNameParts.add(String.format("%d人", list.size()));
        }

        String startDTStr = null;
        if (!StringUtils.isEmpty(start)) {
            startDTStr = start.replaceAll("-", "");
            fileNameParts.add(startDTStr);
        }

        String endDTStr = null;
        if (!StringUtils.isEmpty(end)) {
            endDTStr = end.replaceAll("-", "");
            if (!endDTStr.equals(startDTStr)) {
                fileNameParts.add(endDTStr);
            }
        }

        ExcelUtils.flush(response, FormExport.class, list, String.join("_", fileNameParts), null);

        return null;
    }

    /**
     * 保存对象
     * @param taResumeWorkForm 实体对象
     * @return
     */
    @RequestMapping(value="/h5/resume-work-form",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taResumeWorkFormAdd(@ApiParam("保存内容") @RequestBody TaResumeWorkForm taResumeWorkForm) throws Exception{

        taResumeWorkForm.setFormId(null);

        if (StringUtils.isEmpty(taResumeWorkForm.getOrgId())) {
            return ResponseBean.error("请选择您所属企业");
        }
        if (StringUtils.isEmpty(taResumeWorkForm.getUserName())) {
            return ResponseBean.error("请填写您的姓名");
        }
//        if (StringUtils.isEmpty(taResumeWorkForm.getAntigenImage())) {
//            return ResponseBean.error("请上传抗原截图");
//        }
//        if (null == taResumeWorkForm.getAntigenIsNormal()) {
//            return ResponseBean.error("请设置抗原是否正常");
//        }
        if (StringUtils.isEmpty(taResumeWorkForm.getNucleicImage())) {
            return ResponseBean.error("请上传核酸检测截图");
        }
        if (null == taResumeWorkForm.getNucleicIsNormal()) {
            return ResponseBean.error("请设置核酸检测结果是否正常");
        }

        if (iTaResumeWorkFormService.save(taResumeWorkForm)){
            return ResponseBean.success(taResumeWorkForm);
        } else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/resume-work-form/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taResumeWorkFormDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaResumeWorkForm resumeWorkForm = iTaResumeWorkFormService.getById(id);
        if (null == resumeWorkForm || Constants.STATUS_DELETE == resumeWorkForm.getStatus()) {
            return ResponseBean.error("找不到数据");
        }

        String userId = null;
        String loginDevice = StpUtil.getLoginDevice();
        if (Constants.LOGIN_TYPE_ORG.equals(loginDevice)) {
            TaUser taUser = currentUser();
            userId = taUser.getUserId();
            if (!taUser.getOrgId().equals(resumeWorkForm.getOrgId())) {
                return ResponseBean.error("暂无权限");
            }
        } else {
            SysUser sysUser = currentAdmin();
            userId = sysUser.getUserId();
        }

        if(iTaResumeWorkFormService.removeLogicByUser(id, userId, loginDevice)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taResumeWorkForm 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taResumeWorkForm/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taResumeWorkFormUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaResumeWorkForm taResumeWorkForm) throws Exception{
//
//        if (iTaResumeWorkFormService.updateById(taResumeWorkForm)){
//            return ResponseBean.success(iTaResumeWorkFormService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taResumeWorkForm/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taResumeWorkFormGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaResumeWorkFormService.getById(id));
//    }
}
