package com.njyunzhi.ubpa.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.ubpa.common.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.njyunzhi.ubpa.service.ITaUserService;
import com.njyunzhi.ubpa.entity.TaUser;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 企业用户表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-05-01
 */

@Api(tags = "企业用户表")
@RestController
@RequestMapping("/")
public class TaUserController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaUserController.class);

    @Autowired
    public ITaUserService iTaUserService;


//    /**
//     * 分页查询列表
//     * @param pageNum
//     * @param pageSize
//     * @return
//     */
//    @RequestMapping(value="/taUser",method= RequestMethod.GET)
//    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taUserList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
//									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{
//
//		    IPage<TaUser> pg = new Page<>(pageNum, pageSize);
//            QueryWrapper<TaUser> queryWrapper = new QueryWrapper<>();
//            queryWrapper.orderByDesc("create_date");
//
//            IPage<TaUser> result = iTaUserService.page(pg, queryWrapper);
//            return ResponseBean.success(result);
//    }
//
//    /**
//     * 保存对象
//     * @param taUser 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taUser",method= RequestMethod.POST)
//    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
//    public ResponseBean taUserAdd(@ApiParam("保存内容") @RequestBody TaUser taUser) throws Exception{
//
//        if (iTaUserService.save(taUser)){
//            return ResponseBean.success(taUser);
//        }else {
//            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }


    /**
     * 保存对象
     * @param taUser 实体对象
     * @return
     */
    @RequestMapping(value="/admin/org/{orgId}/user",method= RequestMethod.POST)
    @ApiOperation(value="保存或修改对象", notes = "保存或修改对象", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taUserAdd(@ApiParam("企业ID") @PathVariable String orgId,
                                  @ApiParam("保存内容") @RequestBody TaUser taUser) throws Exception{
        boolean isAdd = StringUtils.isEmpty(taUser.getUserId());
        taUser.setOrgId(orgId);

        if (isAdd) {
            TaUser orgin = iTaUserService.getOrgAdmin(orgId);
            if (null != orgin) {
                return ResponseBean.error("参数错误, 企业已存在管理员");
            }
        }

        if (StringUtils.isEmpty(taUser.getUserName())) {
            return ResponseBean.error("用户姓名不能为空");
        }

        if (StringUtils.isEmpty(taUser.getPhone())) {
            return ResponseBean.error("用户手机不能为空");
        }

        TaUser origin = iTaUserService.getExistBy("phone", taUser.getPhone(), false, true);
        if (null != origin && (isAdd || !taUser.getUserId().equals(origin.getUserId()))) {
            return ResponseBean.error("用户手机已存在");
        }

        if (!StringUtils.isEmpty(taUser.getLoginName())) {
            origin = iTaUserService.getExistBy("login_name", taUser.getLoginName(), false, true);
            if (null != origin && (isAdd || !taUser.getUserId().equals(origin.getUserId()))) {
                return ResponseBean.error("用户登录账号已存在");
            }
        }

        if (isAdd) {
            taUser.setUserId(StringUtils.uuid());
        }

        if (!StringUtils.isEmpty(taUser.getPassword())) {
            String newPass = EncryptUtils.md5(taUser.getPassword(), taUser.getUserId());
            taUser.setPassword(newPass);
        }

        boolean isOk = isAdd ? iTaUserService.save(taUser) : iTaUserService.updateById(taUser);

        if (isOk){
            return ResponseBean.success(taUser);
        } else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }
//
//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taUser/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taUserDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaUserService.removeById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taUser 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taUser/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taUserUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaUser taUser) throws Exception{
//
//        if (iTaUserService.updateById(taUser)){
//            return ResponseBean.success(iTaUserService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/user/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taUserGet(@ApiParam("人员ID") @PathVariable String id) throws Exception{
        TaUser taUser = iTaUserService.getById(id);
        if (taUser.getStatus() == Constants.STATUS_DELETE) {
            return ResponseBean.error("找不到数据");
        }

        String loginDevice = StpUtil.getLoginDevice();
        if (Constants.LOGIN_TYPE_ORG.equals(loginDevice)) {
            TaUser current = currentUser();
            if (!current.getOrgId().equals(taUser.getOrgId())) {
                return ResponseBean.error("暂无权限");
            }
        }

        taUser.setPassword(null);
        return ResponseBean.success(taUser);
    }
}
