package com.njyunzhi.ubpa.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.ubpa.common.BaseController;
import com.njyunzhi.ubpa.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.njyunzhi.ubpa.service.ITsResumeWorkFormService;
import com.njyunzhi.ubpa.entity.TsResumeWorkForm;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 通用统计 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-05-16
 */

@Api(tags = "通用统计")
@RestController
@RequestMapping("/")
public class TsResumeWorkFormController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TsResumeWorkFormController.class);

    @Autowired
    public ITsResumeWorkFormService iTsResumeWorkFormService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/tsResumeWorkForm",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tsResumeWorkFormList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TsResumeWorkForm> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TsResumeWorkForm> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TsResumeWorkForm> result = iTsResumeWorkFormService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param tsResumeWorkForm 实体对象
     * @return
     */
    @RequestMapping(value="/tsResumeWorkForm",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean tsResumeWorkFormAdd(@ApiParam("保存内容") @RequestBody TsResumeWorkForm tsResumeWorkForm) throws Exception{

        if (iTsResumeWorkFormService.save(tsResumeWorkForm)){
            return ResponseBean.success(tsResumeWorkForm);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tsResumeWorkForm/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean tsResumeWorkFormDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTsResumeWorkFormService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tsResumeWorkForm 实体对象
     * @return
     */
    @RequestMapping(value="/tsResumeWorkForm/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean tsResumeWorkFormUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TsResumeWorkForm tsResumeWorkForm) throws Exception{

        if (iTsResumeWorkFormService.updateById(tsResumeWorkForm)){
            return ResponseBean.success(iTsResumeWorkFormService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tsResumeWorkForm/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tsResumeWorkFormGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTsResumeWorkFormService.getById(id));
    }
}
